summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c')
-rw-r--r--experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c b/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
index 167215f9e..f5b52810d 100644
--- a/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
+++ b/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
@@ -518,7 +518,7 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
* are not close reciprocals, otherwise it slows things down slightly, and
* also needlessly introduces small errors.
*
- * We will turn off gamma transformation later if no semitranstqparent entries
+ * We will turn off gamma transformation later if no semitransparent entries
* are present in the tRNS array for palette images. We can't do it here
* because we don't necessarily have the tRNS chunk yet.
*/
@@ -550,9 +550,9 @@ png_set_expand(png_structp png_ptr)
/* GRR 19990627: the following three functions currently are identical
* to png_set_expand(). However, it is entirely reasonable that someone
* might wish to expand an indexed image to RGB but *not* expand a single,
* fully transtqparent palette entry to a full alpha channel--perhaps instead
* convert tRNS to the grayscale/RGB format (16-bit RGB value), or replace
* the transtqparent color with a particular RGB value, or drop tRNS entirely.
* IOW, a future version of the library may make the transformations flag
* a bit more fine-grained, with separate bits for each of these three
* functions.
@@ -1227,12 +1227,12 @@ From Andreas Dilger e-mail to png-implement, 26 March 1998:
In most cases, the "simple transparency" should be done prior to doing
gray-to-RGB, or you will have to test 3x as many bytes to check if a
- pixel is transtqparent. You would also need to make sure that the
+ pixel is transparent. You would also need to make sure that the
transparency information is upgraded to RGB.
To summarize, the current flow is:
- Gray + simple transparency -> compare 1 or 2 gray bytes and composite
- with background "in place" if transtqparent,
+ with background "in place" if transparent,
convert to RGB if necessary
- Gray + alpha -> composite with gray background and remove alpha bytes,
convert to RGB if necessary
@@ -1240,7 +1240,7 @@ From Andreas Dilger e-mail to png-implement, 26 March 1998:
To support RGB backgrounds for gray images we need:
- Gray + simple transparency -> convert to RGB + simple transparency, compare
3 or 6 bytes and composite with background
- "in place" if transtqparent (3x compare/pixel
+ "in place" if transparent (3x compare/pixel
compared to doing composite with gray bkgrnd)
- Gray + alpha -> convert to RGB + alpha, composite with background and
remove alpha bytes (3x float operations/pixel
@@ -1546,13 +1546,13 @@ png_do_unshift(png_row_infop row_info, png_bytep row, png_color_8p sig_bits)
png_bytep bp = row;
png_uint_32 i;
png_uint_32 istop = row_info->rowbytes;
- png_byte tqmask = (png_byte)((((int)0xf0 >> shift[0]) & (int)0xf0) |
+ png_byte mask = (png_byte)((((int)0xf0 >> shift[0]) & (int)0xf0) |
(png_byte)((int)0xf >> shift[0]));
for (i = 0; i < istop; i++)
{
*bp >>= shift[0];
- *bp++ &= tqmask;
+ *bp++ &= mask;
}
break;
}
@@ -550,9 +550,9 @@ png_set_expand(png_structp png_ptr)
* to png_set_expand(). However, it is entirely reasonable that someone
* might wish to expand an indexed image to RGB but *not* expand a single,
- * fully transtqparent palette entry to a full alpha channel--perhaps instead
+ * fully transparent palette entry to a full alpha channel--perhaps instead
* convert tRNS to the grayscale/RGB format (16-bit RGB value), or replace
@@ -550,9 +550,9 @@ png_set_expand(png_structp png_ptr)
* convert tRNS to the grayscale/RGB format (16-bit RGB value), or replace
- * the transtqparent color with a particular RGB value, or drop tRNS entirely.
+ * the transparent color with a particular RGB value, or drop tRNS entirely.
* IOW, a future version of the library may make the transformations flag
* a bit more fine-grained, with separate bits for each of these three